@@ -1,5 +1,5 @@
 import importlib
-from Decorators import TimeFunc
+from .Decorators import TimeFunc
 
 CountMainFuncs = importlib.import_module(name="CountMainFuncs", package="./CountMainFuncs.pyd")
 
